(-query q)Like query, but returns a locator instead of a SeqableLocator,
it's usually used inside the default defcommands.
Like `query`, but returns a locator instead of a `SeqableLocator`, it's usually used inside the default `defcommands`.
(click q)(count* locator)(defcommand name doc-string? [params*] body)Like defn, but adds some extra properties to the function relevant
to Walstrom commands.
Like `defn`, but adds some extra properties to the function relevant to Walstrom commands.
(download-file q)(fill q value)(fill-many coll)(find-one-by-text q text)(get-page)(go-back)(keyboard-press key)Press keyboard. See https://playwright.dev/docs/api/class-keyboard. E.g. `(keyboard-press "Enter")`
(-locator _)(navigate url)(parse-json-string s)(query q)(query->selector q)(refresh)(select q option)Possible values for options are
Possible values for options are
- string
- {:index n}
- {:label "..."}(text-contents locator)(upload-file q file-path)(url)(visible? q)(wait q)(wait-for q)(wait-for q {:keys [state timeout]})state may be :hidden, :visible, :attached or :detached, defaults to :visible.
timeout is in milliseconds, defaults to the page timeout.
See https://playwright.dev/java/docs/api/class-page#page-wait-for-selector for more context.
`state` may be :hidden, :visible, :attached or :detached, defaults to `:visible`. `timeout` is in milliseconds, defaults to the page timeout. See https://playwright.dev/java/docs/api/class-page#page-wait-for-selector for more context.
(with-opts opts & body)(with-page page & body)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |